# ScienceDesk Python helpers

This module provides Python code to help you interact with and extend the
ScienceDesk platform.

## Modules

- api: helpers to interact with the ScienceDesk API
- proc: helpers to write ScienceDesk algorithms


## Documentation
You can check the current documentation at [Read The Docs](https://sciencedesk-helper-library.readthedocs.io)
